cmd

package
v0.1.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 28, 2026 License: MIT Imports: 32 Imported by: 0

Documentation

Overview

NOTE: cross compile safe

TODO: we build simple provisioning logic for devs with terraform

NextDeploy - A clean and powerful CLI for Next.js deployments

TODO: fix logic to get env file and run with latest image just locally

Index

Constants

This section is empty.

Variables

var (
	Elogs = shared.PackageLogger("EncryptFiles::", "🔐 Encrypt Files::")
)
var (
	PrepLogs = shared.PackageLogger("prepare", "🔧 PREPARE")
)

Functions

func CreateAppDirectory

func CreateAppDirectory(ctx context.Context, serverName string, cfg config.ServerConfig, out io.Writer) error

func Execute

func Execute()

Types

type Config

type Config struct {
	Image string `yaml:"image"`
}

type PackageManager

type PackageManager string

func (PackageManager) String

func (pm PackageManager) String() string

Jump to