Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetCommitHash ¶
func GetCurrentBranch ¶
GetCurrentBranch returns the name of the current Git branch in the working directory. Returns an error if the directory is not a Git repository or if the command fails.
func GetGitCommitHash ¶
func GetSecondLatestCommitHash ¶
GetSecondLatestCommitHash returns the second latest commit hash in the current repository
func GetSecondLatestCommitHashAlt ¶
Alternative version using git rev-parse for better performance
Types ¶
type RepositoryInfo ¶
func GetRepositoryInfo ¶
func GetRepositoryInfo() (*RepositoryInfo, error)
Click to show internal directories.
Click to hide internal directories.