Documentation
¶
Overview ¶
NOTE: cross compile safe
TODO: we build simple provisioning logic for devs with terraform
NextDeploy - A clean and powerful CLI for Next.js deployments ¶
TODO: fix logic to get env file and run with latest image just locally
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Elogs = shared.PackageLogger("EncryptFiles::", "🔐 Encrypt Files::")
)
var (
PrepLogs = shared.PackageLogger("prepare", "🔧 PREPARE")
)
Functions ¶
func CreateAppDirectory ¶
Types ¶
type PackageManager ¶
type PackageManager string
func (PackageManager) String ¶
func (pm PackageManager) String() string
Click to show internal directories.
Click to hide internal directories.