Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Option ¶
Option is a functional option pattern type for configuring Store
func WithEnvFile ¶
WithEnvFile configures the store to load initial data from an env file
type Store ¶
type Store[T any] struct { // contains filtered or unexported fields }
Click to show internal directories.
Click to hide internal directories.