git

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetCommitHash

func GetCommitHash() (string, error)

func GetCurrentBranch

func GetCurrentBranch() (string, error)

GetCurrentBranch returns the name of the current Git branch in the working directory. Returns an error if the directory is not a Git repository or if the command fails.

func GetGitCommitHash

func GetGitCommitHash() (string, error)

func GetSecondLatestCommitHash

func GetSecondLatestCommitHash() (string, error)

GetSecondLatestCommitHash returns the second latest commit hash in the current repository

func GetSecondLatestCommitHashAlt

func GetSecondLatestCommitHashAlt() (string, error)

Alternative version using git rev-parse for better performance

func IsDirty

func IsDirty() bool

Types

type RepositoryInfo

type RepositoryInfo struct {
	CommitHash string
	BranchName string
	IsDirty    bool
}

func GetRepositoryInfo

func GetRepositoryInfo() (*RepositoryInfo, error)

Jump to